---
template: mainpanel
source_form: markdown
name: Trello Cardlist Release Backlog: Tasks
updated: October 2016
title: Trello Cardlist Release Backlog: Tasks
---
### Release Backlog: Tasks

* 0\.1.23 - - - - - (tasks)
* 57\. Blog post: Pyxie structure #website
* Release tasks
